searchData={"items":[{"type":"module","title":"ExZstd","doc":"ExZstd aims to expose ZSTD stable interfaces in an idiomatic Elixir way.\nIf you have any doubt the official documentation resides here: https://github.com/facebook/zstd/blob/v1.5.5/lib/zstd.h.\nThe naming used in this wrapper library aims to reflect upstream closely where possible.\n\n#","ref":"ExZstd.html"},{"type":"module","title":"Simple API - ExZstd","doc":"99% of users only needs this API, it's composed by two methods: `compress` and `decompress` that do what they say on the tin.\nNote that decompress reads the final size from the header, so only pass trusted input to this function. To decompress untrusted input see\n`decompress_stream` under the stream API section.\n\n#","ref":"ExZstd.html#module-simple-api"},{"type":"module","title":"Context API - ExZstd","doc":"This API allows the caller to reuse the same context for multiple compressions and specify advanced parameters, see the `zstd.h` header to\nknow more. Your code will probably look simlar to the follwing:\n```elixir\nalias ExZstd.CCtx\nalias ExZstd.Cparam\nalias ExZstd.Cparam.Strategy\nalias ExZstd.DCtx\n\ndata = :crypto.strong_rand_bytes(16)\n\ncctx = CCtx.create()\n  |> CCtx.set_cparam(Cparam.compression_level, 3)\n  |> CCtx.set_cparam(Cparam.strategy, Strategy.btopt)\n\ncompressed_data = ExZstd.CCtx.compress!(cctx, data)\n\ndctx = DCtx.create()\noriginal_data = ExZstd.DCtx.decompress(dctx, compressed_data)\n\ndata == original_data\n```\n\n*Important note*: the various context API that set/get parameters will modify the underlying context object, *not* create a new one. So the two following snippets both modify `cctx`:\n```elixir\n# first\ncctx = CCtx.new()\nCCtx.set_cparam(cctx, param.compression_level, 3)\n\n#second\ncctx = CCtx.new() |> CCtx.set_cparam(Cparam.compression_level, 3)\n```\n\n#","ref":"ExZstd.html#module-context-api"},{"type":"module","title":"Threads - ExZstd","doc":"- 1 context = 1 thread AND no simultaneous compressions\n- If you pass the right parameters you'll be able to use the multithreading capabilities of zstd. The thread pool would live outside the BEAM so avoid it unless absolutely necessary.\n\n#","ref":"ExZstd.html#module-threads"},{"type":"module","title":"Stream API - ExZstd","doc":"The stream API allows you to compress and decompress multiple data in frames lazily. Use this api if:\n- you want to compress complex data (e.g. iolists) without transforming it into a binary first.\n- you want to decompress untrusted data\n- you want to control how the input is split into multiple frames\n\nExample:\n\n```elixir\nalias ExZstd.Cctx\nalias ExZstd.Dctx\nalias ExZstd.Cparam\nalias ExZstd.Dparam\n\ncctx = CCtx.create()\ndctx = DCtx.create()\n\n# compress the data\nfirst_chunk = CCtx.compress_stream!(cctx, Fixtures.data(), CCtx.stream_continue())\nsecond_chunk = CCtx.compress_stream!(cctx, Fixtures.data2(), CCtx.stream_end())\n\n# retreive the input\nDCtx.decompress_stream!(dctx, first_chunk)   DCtx.decompress_stream!(dctx, second_chunk)\n```","ref":"ExZstd.html#module-stream-api"},{"type":"module","title":"Dictionary API - ExZstd","doc":"You can use the dictionary API to further improve compression size.\nExcerpts from the `zdict.h` header:\n- In general, it's recommended to provide a few thousands samples, though this can vary a lot.\n- It's recommended that total size of all samples be about ~x100 times the target size of dictionary.\n\nYou can train the dictionaries by using the `zstd --train` interface of the CLI. At the moment this interface is *not* tested as part of `ex_zstd` test suite.\n\nExample:\n\n```elixir\nalias ExZstd.CCtx\nalias ExZstd.Cparam\nalias ExZstd.Cparam.Strategy\nalias ExZstd.DCtx\n\ndata = :crypto.strong_rand_bytes(16)\ndictionary = File.read!(\"my_dictionary.bin\")\n\ncctx = CCtx.create()\nCCtx.load_dictionary(dictionary)\n\ncompressed_data = ExZstd.CCtx.compress!(cctx, data)\n\ndctx = DCtx.create()\nDCtx.load_dictionary(dictionary)\noriginal_data = ExZstd.DCtx.decompress(dctx, compressed_data)\n\ndata == original_data\n```","ref":"ExZstd.html#module-dictionary-api"},{"type":"function","title":"ExZstd.compress/2","doc":"Identical to `compress!`. Wraps the result in a maybe instead of raising.","ref":"ExZstd.html#compress/2"},{"type":"function","title":"ExZstd.compress!/2","doc":"Compresses a chunk of data.","ref":"ExZstd.html#compress!/2"},{"type":"function","title":"ExZstd.content_size_unknown/0","doc":"Returns ZSTD_CONTENTSIZE_UNKNOWN.","ref":"ExZstd.html#content_size_unknown/0"},{"type":"function","title":"ExZstd.decompress/1","doc":"Identical to `decompress!`. Wraps the result in a maybe instead of raising.\n\nNote: this functions reads the header to find out the size of the decompressed data. Only feed it trusted input!","ref":"ExZstd.html#decompress/1"},{"type":"function","title":"ExZstd.decompress!/1","doc":"Decompresses a chunk of data. If `:content_size_unknown` is returned stream decompression can be still attempted.\n\nNote: this functions reads the header to find out the size of the decompressed data. Only feed it trusted input!","ref":"ExZstd.html#decompress!/1"},{"type":"function","title":"ExZstd.default_compression_level/0","doc":"","ref":"ExZstd.html#default_compression_level/0"},{"type":"function","title":"ExZstd.get_cparam_bounds/1","doc":"Returns the boundaries for a compresson parameter.","ref":"ExZstd.html#get_cparam_bounds/1"},{"type":"function","title":"ExZstd.get_dparam_bounds/1","doc":"Returns the boundaries of a decompression parameter.","ref":"ExZstd.html#get_dparam_bounds/1"},{"type":"function","title":"ExZstd.reset_parameters/0","doc":"","ref":"ExZstd.html#reset_parameters/0"},{"type":"function","title":"ExZstd.reset_session_and_parameters/0","doc":"","ref":"ExZstd.html#reset_session_and_parameters/0"},{"type":"function","title":"ExZstd.reset_session_only/0","doc":"","ref":"ExZstd.html#reset_session_only/0"},{"type":"type","title":"ExZstd.decompression_error/0","doc":"","ref":"ExZstd.html#t:decompression_error/0"},{"type":"type","title":"ExZstd.error/0","doc":"","ref":"ExZstd.html#t:error/0"},{"type":"type","title":"ExZstd.reset_directive/0","doc":"","ref":"ExZstd.html#t:reset_directive/0"},{"type":"module","title":"ExZstd.CCtx","doc":"Compression context. To know more check out the `ExZstd` doc.","ref":"ExZstd.CCtx.html"},{"type":"function","title":"ExZstd.CCtx.compress/2","doc":"Identical to `compress!`. Wraps the result in a maybe instead of raising.","ref":"ExZstd.CCtx.html#compress/2"},{"type":"function","title":"ExZstd.CCtx.compress!/2","doc":"Compresses a chunk of data.","ref":"ExZstd.CCtx.html#compress!/2"},{"type":"function","title":"ExZstd.CCtx.compress_stream/3","doc":"Identical to `compress_stream!`. Wraps the result in a maybe instead of raising.","ref":"ExZstd.CCtx.html#compress_stream/3"},{"type":"function","title":"ExZstd.CCtx.compress_stream!/3","doc":"Writes a chunk of data into a compression stream.","ref":"ExZstd.CCtx.html#compress_stream!/3"},{"type":"function","title":"ExZstd.CCtx.get_cparam/2","doc":"Gets the value of a parameter of a compression context (cparam).\nSee `ExZstd.Cparam` for more information.","ref":"ExZstd.CCtx.html#get_cparam/2"},{"type":"function","title":"ExZstd.CCtx.load_dictionary/2","doc":"Loads a decompression dictionary inside the decompresson context.","ref":"ExZstd.CCtx.html#load_dictionary/2"},{"type":"function","title":"ExZstd.CCtx.new/0","doc":"Creates a compression context.","ref":"ExZstd.CCtx.html#new/0"},{"type":"function","title":"ExZstd.CCtx.reset/2","doc":"Resets the compression context, interrupting any ongoing compression and resetting the parameters to their default values.","ref":"ExZstd.CCtx.html#reset/2"},{"type":"function","title":"ExZstd.CCtx.set_cparam/3","doc":"Sets a parameter of a compression context (cparam) to the given value.\nSee `ExZstd.Cparam` for more information.","ref":"ExZstd.CCtx.html#set_cparam/3"},{"type":"function","title":"ExZstd.CCtx.set_pledged_src_size/2","doc":"Sets the size of the following frame, only effective with stream compression.","ref":"ExZstd.CCtx.html#set_pledged_src_size/2"},{"type":"function","title":"ExZstd.CCtx.stream_continue/0","doc":"","ref":"ExZstd.CCtx.html#stream_continue/0"},{"type":"function","title":"ExZstd.CCtx.stream_end/0","doc":"","ref":"ExZstd.CCtx.html#stream_end/0"},{"type":"function","title":"ExZstd.CCtx.stream_flush/0","doc":"","ref":"ExZstd.CCtx.html#stream_flush/0"},{"type":"type","title":"ExZstd.CCtx.stream_end_directive/0","doc":"","ref":"ExZstd.CCtx.html#t:stream_end_directive/0"},{"type":"opaque","title":"ExZstd.CCtx.t/0","doc":"","ref":"ExZstd.CCtx.html#t:t/0"},{"type":"module","title":"ExZstd.Cparam","doc":"Helpers to convert cparam names into numbers. Consult zstd.h to know more.","ref":"ExZstd.Cparam.html"},{"type":"function","title":"ExZstd.Cparam.chain_log/0","doc":"","ref":"ExZstd.Cparam.html#chain_log/0"},{"type":"function","title":"ExZstd.Cparam.checksum_flag/0","doc":"","ref":"ExZstd.Cparam.html#checksum_flag/0"},{"type":"function","title":"ExZstd.Cparam.compression_level/0","doc":"","ref":"ExZstd.Cparam.html#compression_level/0"},{"type":"function","title":"ExZstd.Cparam.content_size_flag/0","doc":"","ref":"ExZstd.Cparam.html#content_size_flag/0"},{"type":"function","title":"ExZstd.Cparam.dict_id_flag/0","doc":"","ref":"ExZstd.Cparam.html#dict_id_flag/0"},{"type":"function","title":"ExZstd.Cparam.enable_long_distance_matching/0","doc":"","ref":"ExZstd.Cparam.html#enable_long_distance_matching/0"},{"type":"function","title":"ExZstd.Cparam.hash_log/0","doc":"","ref":"ExZstd.Cparam.html#hash_log/0"},{"type":"function","title":"ExZstd.Cparam.job_size/0","doc":"","ref":"ExZstd.Cparam.html#job_size/0"},{"type":"function","title":"ExZstd.Cparam.ldm_bucket_size_log/0","doc":"","ref":"ExZstd.Cparam.html#ldm_bucket_size_log/0"},{"type":"function","title":"ExZstd.Cparam.ldm_hash_log/0","doc":"","ref":"ExZstd.Cparam.html#ldm_hash_log/0"},{"type":"function","title":"ExZstd.Cparam.ldm_hash_rate_log/0","doc":"","ref":"ExZstd.Cparam.html#ldm_hash_rate_log/0"},{"type":"function","title":"ExZstd.Cparam.ldm_min_match/0","doc":"","ref":"ExZstd.Cparam.html#ldm_min_match/0"},{"type":"function","title":"ExZstd.Cparam.min_match/0","doc":"","ref":"ExZstd.Cparam.html#min_match/0"},{"type":"function","title":"ExZstd.Cparam.nb_workers/0","doc":"","ref":"ExZstd.Cparam.html#nb_workers/0"},{"type":"function","title":"ExZstd.Cparam.overlap_log/0","doc":"","ref":"ExZstd.Cparam.html#overlap_log/0"},{"type":"function","title":"ExZstd.Cparam.search_log/0","doc":"","ref":"ExZstd.Cparam.html#search_log/0"},{"type":"function","title":"ExZstd.Cparam.strategy/0","doc":"","ref":"ExZstd.Cparam.html#strategy/0"},{"type":"function","title":"ExZstd.Cparam.target_length/0","doc":"","ref":"ExZstd.Cparam.html#target_length/0"},{"type":"function","title":"ExZstd.Cparam.window_log/0","doc":"","ref":"ExZstd.Cparam.html#window_log/0"},{"type":"type","title":"ExZstd.Cparam.t/0","doc":"","ref":"ExZstd.Cparam.html#t:t/0"},{"type":"module","title":"ExZstd.Cparam.Strategy","doc":"Helpers to convert the values of the `strategy` cparam into numbers. Consult zstd.h to know more.","ref":"ExZstd.Cparam.Strategy.html"},{"type":"function","title":"ExZstd.Cparam.Strategy.btlazy2/0","doc":"","ref":"ExZstd.Cparam.Strategy.html#btlazy2/0"},{"type":"function","title":"ExZstd.Cparam.Strategy.btopt/0","doc":"","ref":"ExZstd.Cparam.Strategy.html#btopt/0"},{"type":"function","title":"ExZstd.Cparam.Strategy.btultra2/0","doc":"","ref":"ExZstd.Cparam.Strategy.html#btultra2/0"},{"type":"function","title":"ExZstd.Cparam.Strategy.btultra/0","doc":"","ref":"ExZstd.Cparam.Strategy.html#btultra/0"},{"type":"function","title":"ExZstd.Cparam.Strategy.dfast/0","doc":"","ref":"ExZstd.Cparam.Strategy.html#dfast/0"},{"type":"function","title":"ExZstd.Cparam.Strategy.fast/0","doc":"","ref":"ExZstd.Cparam.Strategy.html#fast/0"},{"type":"function","title":"ExZstd.Cparam.Strategy.greedy/0","doc":"","ref":"ExZstd.Cparam.Strategy.html#greedy/0"},{"type":"function","title":"ExZstd.Cparam.Strategy.lazy2/0","doc":"","ref":"ExZstd.Cparam.Strategy.html#lazy2/0"},{"type":"function","title":"ExZstd.Cparam.Strategy.lazy/0","doc":"","ref":"ExZstd.Cparam.Strategy.html#lazy/0"},{"type":"module","title":"ExZstd.DCtx","doc":"Decompression context. To know more check out the `ExZstd` doc.","ref":"ExZstd.DCtx.html"},{"type":"function","title":"ExZstd.DCtx.decompress/2","doc":"Identical to `decompress!`. Wraps the result in a maybe instead of raising.\n\nNote: this functions reads the header to find out the size of the decompressed data. Only feed it trusted input!","ref":"ExZstd.DCtx.html#decompress/2"},{"type":"function","title":"ExZstd.DCtx.decompress!/2","doc":"Decompresses a chunk of data using the given context. If `:content_size_unknown` is returned stream decompression can be still attempted.\n\nNote: this functions reads the header to find out the size of the decompressed data. Only feed it trusted input!","ref":"ExZstd.DCtx.html#decompress!/2"},{"type":"function","title":"ExZstd.DCtx.decompress_stream/2","doc":"Identical to `decompress_stream`. Wraps the result in a maybe instead of raising.","ref":"ExZstd.DCtx.html#decompress_stream/2"},{"type":"function","title":"ExZstd.DCtx.decompress_stream!/2","doc":"Decompresses multiple frames with streaming.","ref":"ExZstd.DCtx.html#decompress_stream!/2"},{"type":"function","title":"ExZstd.DCtx.get_dparam/2","doc":"Gets the value of a parameter of a decompression context (dparam).\nSee `ExZstd.Dparam` for more information.","ref":"ExZstd.DCtx.html#get_dparam/2"},{"type":"function","title":"ExZstd.DCtx.load_dictionary/2","doc":"Loads a decompression dictionary inside the decompresson context.","ref":"ExZstd.DCtx.html#load_dictionary/2"},{"type":"function","title":"ExZstd.DCtx.new/0","doc":"Creates a decompression context","ref":"ExZstd.DCtx.html#new/0"},{"type":"function","title":"ExZstd.DCtx.reset/2","doc":"Resets the decompression context, interrupting any ongoing decompression and resetting the parameters to their default values.","ref":"ExZstd.DCtx.html#reset/2"},{"type":"function","title":"ExZstd.DCtx.set_dparam/3","doc":"Sets a parameter of a decompression context (dparam) to the given value.\nSee `ExZstd.Dparam` for more information.","ref":"ExZstd.DCtx.html#set_dparam/3"},{"type":"opaque","title":"ExZstd.DCtx.t/0","doc":"","ref":"ExZstd.DCtx.html#t:t/0"},{"type":"module","title":"ExZstd.Dparam","doc":"Helpers to convert dparam names into numbers. Consult zstd.h to know more.","ref":"ExZstd.Dparam.html"},{"type":"function","title":"ExZstd.Dparam.window_log_max/0","doc":"","ref":"ExZstd.Dparam.html#window_log_max/0"},{"type":"type","title":"ExZstd.Dparam.t/0","doc":"","ref":"ExZstd.Dparam.html#t:t/0"},{"type":"exception","title":"ExZstd.ContentSizeError","doc":"","ref":"ExZstd.ContentSizeError.html"},{"type":"exception","title":"ExZstd.ContentSizeUnknown","doc":"","ref":"ExZstd.ContentSizeUnknown.html"},{"type":"exception","title":"ExZstd.Error","doc":"","ref":"ExZstd.Error.html"}],"content_type":"text/markdown"}